=============
Basket Client
=============

This is a client for Mozilla's email subscription service,
`basket <https://basket.mozilla.org/>`_. Basket is not a real subscription service, but it talks to a
real one and we don't really care who/what it is.

|latest-version| |python-support| |build-status|

.. |latest-version| image:: https://img.shields.io/pypi/v/basket-client.svg
   :target: https://pypi.org/project/basket-client/
   :alt: Latest version on PyPI

.. |python-support| image:: https://img.shields.io/pypi/pyversions/basket-client
   :target: https://pypi.org/project/basket-client/
   :alt: Supported Python versions

.. |build-status| image:: https://github.com/mozilla/basket-client/actions/workflows/test.yml/badge.svg
   :target: https://github.com/mozilla/basket-client/actions/workflows/test.yml
   :alt: Build Status

Docs
----

Documentation can be found at http://basket-client.rtfd.org/


License
-------

This software is licensed under the BSD License. For more information, read the file ``LICENSE``.
